plotRawData: A generic funciton to plot intensities over time The data...

Description Usage Arguments Value

Description

A generic funciton to plot intensities over time The data should be cleaned, either maually or with readZiessData so that only the time and the data you care about are left. plotRawData will iterate through the rows, printing

Usage

1
plotRawData(raw_data, time_index = 1)

Arguments

raw_data

A dataframe containing the data you wish to plot.

time_index

The index of the column containing all of the 'Time' data.

Value

None


allgenesconsidered/CardiacPeakFinder documentation built on May 10, 2019, 9:23 a.m.